@@ -13,7 +13,7 @@ class SyntaxException(Exception):
     def __init__(self, user_msg, token=None):
         if token:
             message = (
-                "(" + str(token.line) + "," + str(token.start) + "): Error: " + user_msg
+                    "(" + str(token.line) + "," + str(token.start) + "): Error: " + user_msg
             )
         else:
             message = "Error: " + user_msg
@@ -268,7 +268,7 @@ class Builder:
         self._hidden_handled_stack.append(self._hidden_handled)
 
     def next_is_rc(
-        self, type_to_seek: int, hidden_right: bool = True
+            self, type_to_seek: int, hidden_right: bool = True
     ) -> Optional[Token]:
         token = self._stream.LT(1)
         tok_type: int = token.type
@@ -332,58 +332,60 @@ class Builder:
             return False
 
     def handle_hidden_left(self) -> None:
+        if self._hidden_handled:
+            return
         tokens = self._stream.getHiddenTokensToLeft(self._stream.index)
         if tokens:
             for t in tokens:
-                if not self._hidden_handled:
-                    if t.type == Tokens.LINE_COMMENT:
-                        self.comments.append(
-                            Comment(
-                                t.text,
-                                first_token=t,
-                                last_token=t,
-                            )
+                if t.type == Tokens.LINE_COMMENT:
+                    self.comments.append(
+                        Comment(
+                            t.text,
+                            first_token=t,
+                            last_token=t,
                         )
-                    elif t.type == Tokens.COMMENT:
-                        self.comments.append(
-                            Comment(
-                                t.text,
-                                True,
-                                first_token=t,
-                                last_token=t,
-                            )
+                    )
+                elif t.type == Tokens.COMMENT:
+                    self.comments.append(
+                        Comment(
+                            t.text,
+                            True,
+                            first_token=t,
+                            last_token=t,
                         )
-                    elif t.type == Tokens.NEWLINE:
-                        # append n time a None value (indicate newline)
-                        self.comments += t.text.count("\n") * [None]
+                    )
+                elif t.type == Tokens.NEWLINE:
+                    # append n time a None value (indicate newline)
+                    self.comments += t.text.count("\n") * [None]
 
         self._hidden_handled = True
 
     def handle_hidden_right(self) -> None:
+        if self._hidden_handled:
+            return
         tokens = self._stream.getHiddenTokensToRight(self._right_index)
         if tokens:
             for t in tokens:
-                if not self._hidden_handled:
-                    if t.type == Tokens.LINE_COMMENT:
-                        self.comments.append(
-                            Comment(
-                                t.text,
-                                first_token=t,
-                                last_token=t,
-                            )
+                if t.type == Tokens.LINE_COMMENT:
+                    self.comments.append(
+                        Comment(
+                            t.text,
+                            first_token=t,
+                            last_token=t,
                         )
-                    elif t.type == Tokens.COMMENT:
-                        self.comments.append(
-                            Comment(
-                                t.text,
-                                True,
-                                first_token=t,
-                                last_token=t,
-                            )
+                    )
+                elif t.type == Tokens.COMMENT:
+                    self.comments.append(
+                        Comment(
+                            t.text,
+                            True,
+                            first_token=t,
+                            last_token=t,
                         )
-                    elif t.type == Tokens.NEWLINE:
-                        # append n time a None value (indicate newline)
-                        self.comments += t.text.count("\n") * [None]
+                    )
+                elif t.type == Tokens.NEWLINE:
+                    # append n time a None value (indicate newline)
+                    self.comments += t.text.count("\n") * [None]
 
         self._hidden_handled = True
 
@@ -411,7 +413,7 @@ class Builder:
         if idx + 1 < len(self.comments):
             if self.comments[idx] is None and self.comments[idx + 1] is None:
                 # clean list
-                self.comments = self.comments[idx + 2 :]
+                self.comments = self.comments[idx + 2:]
                 return comments
         return []
 
@@ -474,26 +476,31 @@ class Builder:
         stat = self.parse_ret_stat()
         if stat:
             statements.append(stat)
+
+        # force handle trailing hidden tokens after block
+        self._hidden_handled = False
+        self.handle_hidden_right()
         return Block(
             statements,
             first_token=t,
             last_token=statements[-1].last_token if statements else None,
+            comments=self.get_comments(),
         )
 
     def parse_stat(self) -> Statement or None:
         comments = self.get_comments()
 
         stat = (
-            self.parse_assignment()
-            or self.parse_var()
-            or self.parse_while_stat()
-            or self.parse_repeat_stat()
-            or self.parse_local()
-            or self.parse_goto_stat()
-            or self.parse_if_stat()
-            or self.parse_for_stat()
-            or self.parse_function()
-            or self.parse_label()
+                self.parse_assignment()
+                or self.parse_var(is_statement=True)
+                or self.parse_while_stat()
+                or self.parse_repeat_stat()
+                or self.parse_local()
+                or self.parse_goto_stat()
+                or self.parse_if_stat()
+                or self.parse_for_stat()
+                or self.parse_function()
+                or self.parse_label()
         )
 
         if stat:
@@ -570,7 +577,9 @@ class Builder:
             return lua_vars
         return self.failure()
 
-    def parse_var(self) -> Node or bool:
+    # When is_statement is true, root must be a Statement.
+    def parse_var(self, is_statement=False) -> Node or bool:
+        self.save()
         root = self.parse_callee()
         if root:
             tail = self.parse_tail()
@@ -596,11 +605,13 @@ class Builder:
                 tail = self.parse_tail()
                 if tail:
                     self.handle_hidden_right()
-
+            if is_statement and not isinstance(root, Statement):
+                return self.failure()
             self.handle_hidden_right()
+            self.success()
             return root
 
-        return False
+        return self.failure()
 
     def parse_tail(self) -> Node or bool:
         # do not render last hidden
@@ -909,7 +920,7 @@ class Builder:
                             step = 1
                             # optional step
                             if self.next_is(Tokens.COMMA) and self.next_is_rc(
-                                Tokens.COMMA
+                                    Tokens.COMMA
                             ):
                                 step = self.parse_expr()
 
@@ -1282,13 +1293,13 @@ class Builder:
             while True:
                 self.save()
                 if self.next_in_rc(
-                    [
-                        Tokens.BITAND,
-                        Tokens.BITOR,
-                        Tokens.BITNOT,
-                        Tokens.BITRSHIFT,
-                        Tokens.BITRLEFT,
-                    ]
+                        [
+                            Tokens.BITAND,
+                            Tokens.BITOR,
+                            Tokens.BITNOT,
+                            Tokens.BITRSHIFT,
+                            Tokens.BITRLEFT,
+                        ]
                 ):
                     op = self.type
                     right = self.parse_unary_expr()
@@ -1327,7 +1338,7 @@ class Builder:
         self.failure_save()
         if self.next_is_rc(Tokens.LENGTH):
             t: Token = self._LT
-            expr = self.parse_pow_expr()
+            expr = self.parse_expr()
             if expr:
                 self.success()
                 return ULengthOP(expr, first_token=t, last_token=t)
@@ -1363,7 +1374,7 @@ class Builder:
             while True:
                 self.save()
                 if self.next_is_rc(Tokens.POW):
-                    right = self.parse_atom()
+                    right = self.parse_expr()
                     if right:
                         self.success()
                         left = ExpoOp(left, right)
@@ -1391,6 +1402,7 @@ class Builder:
         if self.next_is(Tokens.VARARGS) and self.next_is_rc(Tokens.VARARGS):
             return Varargs()
 
+
         if self.next_is(Tokens.NUMBER) and self.next_is_rc(Tokens.NUMBER):
             # TODO: optimize
             # using python number eval to parse lua number
@@ -1472,6 +1484,7 @@ class Builder:
                     for field in fields:
                         if field.key is None:
                             field.key = Number(array_like_index)
+                            field.between_brackets = True
                             array_like_index += 1
 
                 return Table(fields or [])
